==> fine-web-0.0.1-20220919.091035-231.jar: static/js/base/havedonelist.js <==
var msggrid=$('#BasMessage_havdone_datagrid');
$(function(){
	var nowDate=(new Date()).Format("yyyy-MM-dd");
	$("#endDate").datebox("setValue",nowDate);
	var month=new Date().getMonth()+1;
	var year=new Date().getFullYear();
	if(month==1){
		$("#startDate").datebox("setValue",year-1+"-12"+(new Date()).Format("dd"));
	}else{
		month=month-1<10?"0"+(month-1):(month-1)
		$("#startDate").datebox("setValue",year+"-"+month+(new Date()).Format("-dd"));
	}
	initMsgGrid();
});

function initMsgGrid(){
	msggrid.datagrid({
		// fit:true,
		border:false,
		rownumbers:true,
		fitColumns:true,
		singleSelect:true,
		pagination:true,
		cls:'md',
		height:$("body").height()-140,
		queryParams:{
			msgType : msgType,
			startDate:$("#startDate").datebox("getValue"),
			endDate:$("#endDate").datebox("getValue")
		},
		toolbar:"#BasMessage_havdone_datagrid_tb",
		url:ctx+'/BasMessage/pageHaveDoneList',
	    columns:[[
	    {field:'det',title:'明细',formatter:function(value,row,index){	
	    	return '<div onclick="openToDoListDetail('+row.MSG_ID+',\''+row.MSG_TITLE+'\',\''+row.FORM_CODE+'\','+row.BUSI_MAIN_ID+',\''+(row.MSG_URL?row.MSG_URL:'')+'\')" class="icon-detail iconfont blue">&nbsp;</div>';
	    }},
	    {field:'MSG_ID',title:'msgId',hidden:true},
	    {field:'MSG_TITLE',title:'标题',width:400,align:'left',halign:'center'},
	    {field:'ACCOUNT_NAME',title:'发送人',width:90,align:'center',halign:'center'},
	    {field:'SENDTIME',title:'发送时间',width:120,align:'center',halign:'center'},
	    {field:'DEAL_TIME',title:'办理时间',width:120,align:'center',halign:'center'},
	    {field:'RECEIVE_BY',title:'当前办理人',width:80,align:'center',halign:'center'},
	    {field:'WORKITEMNAME',title:'当前状态',width:80,align:'center',halign:'center',sortable:true,formatter:function(value,row,index){
	    	if(value==null||value==""){
	    		return "结束";
	    	}
	    	return value;
	    }}
	    ]],
	     onDblClickRow:function(index,row){
	    	 openToDoListDetail(row.MSG_ID,row.MSG_TITLE,row.FORM_CODE,row.BUSI_MAIN_ID);
	    }
	    
	});

}
function initBusGrid(){
	busgrid.datagrid({
		// fit:true,
		border:false,
		rownumbers:true,
		fitColumns:true,
		singleSelect:true,
		pagination:true,
		cls:'md',
		height:$("body").height()-140,
		queryParams:{
			msgType : msgType
		},
		toolbar:"#BasMessage_datagrid_tb",
		url:ctx+'/BasMessage/pageBusHaveDoneList',
		columns:[[
		          {field:'det',title:'明细',formatter:function(value,row,index){	
		        	  return '<div onclick="openToDoListDetail('+row.MSG_ID+',\''+row.MSG_TITLE+'\',\''+row.FORM_CODE+'\','+row.BUSI_MAIN_ID+')" class="icon-detail iconfont blue">&nbsp;</div>';
		          }},
		          {field:'MSG_ID',title:'msgId',hidden:true},
		          {field:'MSG_TITLE',title:'标题',width:400},
		          {field:'ACCOUNT_NAME',title:'发送人',width:100},
		          {field:'SENDTIME',title:'发送时间',width:100},
		          {field:'DEAL_TIME',title:'办理时间',width:100}
		          ]],
		          onDblClickRow:function(index,row){
		        	  openToDoListDetail(row.MSG_ID,row.MSG_TITLE,row.FORM_CODE,row.BUSI_MAIN_ID);
		          }
		
	});
	
}

function reloadGrid(){
	msggrid.datagrid('reload');
}
function searchBasMsg_havdone(){
	msggrid.datagrid('load',{
		msgType : msgType,
		search:$("#searchBasMsg_havdone").val(),
		startDate:$("#startDate").datebox("getValue"),
		endDate:$("#endDate").datebox("getValue")
	});
}

function viewFlowhavedone(){
	var row = msggrid.datagrid('getSelected');
	if (row) {
		viewFlowDialog(row.PROCESSINSTID)
	} else {
		alertInfo('请先选择一条数据信息');
	}
}
function openFormDetail(MSG_TITLE,FORM_CODE,BUSI_MAIN_ID,msgId){
	parent.openInMainTab(MSG_TITLE,"/GenForm/form?newpage=true&formcode="+FORM_CODE+"&isdetail=true&id="+BUSI_MAIN_ID+"&msgId="+msgId); 
}
function openToDoListDetail(msgId,msgTitle,formCode,busMainId,msgUrl){
	var url = "" ;
	if(formCode=='EdocApply'){
		url = "/EdocApply/openPrintPage?id="+busMainId +"&msgId="+msgId;
	}else if(!msgUrl&&'BFmRepayPlan_Form'!=formCode){
		url = "/GenForm/form?formcode="+formCode+"&newpage=true&isdetail=true&id="+busMainId+"&msgId="+msgId;
	}else{
//		var url = '/BasMessage/haveDoneDetail?msgid=' + msgId;
		url = msgUrl+getUrlConnector(msgUrl)+'isdetail=true&msgid=' + msgId;
	}
	if (parent && parent.openInMainTab) {
		 url = url + "&isLayer=Y" ;
		 var l_index = parent.layer.open({
			  type: 2,
			  title: msgTitle,
			  closeBtn: 1, //不显示关闭按钮
			  maxmin: true,
			  skin: 'layui-layer-qllan',
		      zIndex:$.fn.window?Math.ceil($.fn.window.defaults.zIndex++):1001,
	          area: [$(top.window).width() + 'px', $(top.window).height() + 'px'],
			  content: [ctx+url, 'no'], //iframe的url，no代表不显示滚动条
			  success: function (layero, index) {
	         },
	         end: function () {  
					reloadGrid();
//					reloadSubGrid();
	         }
	     });
		// parent.layer.full(l_index);
	} else {
		window.open(ctx + url, '_blank');
	}
}



function openOA(url) {
	window.open(url, '_blank');
	return;
}


function rollbackDoneFlow(){
	var row = msggrid.datagrid('getSelected');
	if (row) {
		if(row.WORKITEMNAME){
			$("#rollAct").html(row.WORKITEMNAME);
			$("#receiveBy").html(row.RECEIVE_BY);
		}
		rollbackFlow(row.MSG_ID,row.BUSI_MAIN_ID,row.FORM_CODE,row.PROCESSINSTID);
	} else {
		alertInfo('请先选择一条数据信息');
	}
}

//流程撤回
function rollbackFlow(msgId,busiMainId,formCode,processinstid){
	$('#rollwin').dialog({
        width: 480,
        height: 300,
        modal: true,
        collapsible: false,
        minimizable: false,
        maximizable: false,
        buttons: [{
            text: '确定',
            handler: function () {
            	if(!$("#rolladvice").textbox("getValue")){
            		alertInfo("请输入撤回原因")
            		return;
            	}
            	alertConfirmYes('您确认要撤回流程？', function(r) {
            		if (r) {
            			layer.msg('数据发送中', {icon: 16, shade: 0.3, time: 0});
            			$.ajax({
            				url : ctx + "/wf/rollbackFlow",
            				data : {
            					msgId : msgId,
            					busiMainId : busiMainId,
            					formCode : formCode,
            					processinstid : processinstid,
            					workmemory : $("#rolladvice").textbox("getValue"),
            					roleType : "撤回"
            				},
            				dataType : 'json',
            				success : function(result) {
            			    	 layer.closeAll();
           		                 $('#rollwin').dialog("close");
            					if (result.success) {
            						alertInfo(result.msg);
            						reloadGrid();
//            						if(msgId){
//            							self.location=ctx+"/BasMessage/todoDetail?msgid="+msgId;
//            						}else{
//            							self.location=ctx+"/EdocApply/toOfficePage?id="+busiMainId+"&type="+(formData.edocType==2?"&type=FWNG":"&type=SWDJ");
//            						}
            						//location.reload(true)
            					} else {
            						alertError(result.msg);
            					}
            				}
            			});
            		}
            	});
            }
        }, {
            text: '取消',
            handler: function () {
                $('#rollwin').dialog("close");
            }
        }]
    });
}

==> fine-web-0.0.2-20220909.090829-172.jar: static/js/base/havedonelist.js <==
var msggrid=$('#BasMessage_havdone_datagrid');
$(function(){
	var nowDate=(new Date()).Format("yyyy-MM-dd");
	$("#endDate").datebox("setValue",nowDate);
	var month=new Date().getMonth()+1;
	var year=new Date().getFullYear();
	if(month==1){
		$("#startDate").datebox("setValue",year-1+"-12"+(new Date()).Format("dd"));
	}else{
		month=month-1<10?"0"+(month-1):(month-1)
		$("#startDate").datebox("setValue",year+"-"+month+(new Date()).Format("-dd"));
	}
	initMsgGrid();
});

function initMsgGrid(){
	msggrid.datagrid({
		// fit:true,
		border:false,
		rownumbers:true,
		fitColumns:true,
		singleSelect:true,
		pagination:true,
		cls:'md',
		height:$("body").height()-140,
		queryParams:{
			msgType : msgType,
			startDate:$("#startDate").datebox("getValue"),
			endDate:$("#endDate").datebox("getValue")
		},
		toolbar:"#BasMessage_havdone_datagrid_tb",
		url:ctx+'/BasMessage/pageHaveDoneList',
	    columns:[[
	    {field:'det',title:'明细',formatter:function(value,row,index){	
	    	return '<div onclick="openToDoListDetail('+row.MSG_ID+',\''+row.MSG_TITLE+'\',\''+row.FORM_CODE+'\','+row.BUSI_MAIN_ID+',\''+(row.MSG_URL?row.MSG_URL:'')+'\')" class="icon-detail iconfont blue">&nbsp;</div>';
	    }},
	    {field:'MSG_ID',title:'msgId',hidden:true},
	    {field:'MSG_TITLE',title:'标题',width:400,align:'left',halign:'center'},
	    {field:'ACCOUNT_NAME',title:'发送人',width:90,align:'center',halign:'center'},
	    {field:'SENDTIME',title:'发送时间',width:120,align:'center',halign:'center'},
	    {field:'DEAL_TIME',title:'办理时间',width:120,align:'center',halign:'center'},
	    {field:'RECEIVE_BY',title:'当前办理人',width:80,align:'center',halign:'center'},
	    {field:'WORKITEMNAME',title:'当前状态',width:80,align:'center',halign:'center',sortable:true,formatter:function(value,row,index){
	    	if(value==null||value==""){
	    		return "结束";
	    	}
	    	return value;
	    }}
	    ]],
	     onDblClickRow:function(index,row){
	    	 openToDoListDetail(row.MSG_ID,row.MSG_TITLE,row.FORM_CODE,row.BUSI_MAIN_ID);
	    }
	    
	});

}
function initBusGrid(){
	busgrid.datagrid({
		// fit:true,
		border:false,
		rownumbers:true,
		fitColumns:true,
		singleSelect:true,
		pagination:true,
		cls:'md',
		height:$("body").height()-140,
		queryParams:{
			msgType : msgType
		},
		toolbar:"#BasMessage_datagrid_tb",
		url:ctx+'/BasMessage/pageBusHaveDoneList',
		columns:[[
		          {field:'det',title:'明细',formatter:function(value,row,index){	
		        	  return '<div onclick="openToDoListDetail('+row.MSG_ID+',\''+row.MSG_TITLE+'\',\''+row.FORM_CODE+'\','+row.BUSI_MAIN_ID+')" class="icon-detail iconfont blue">&nbsp;</div>';
		          }},
		          {field:'MSG_ID',title:'msgId',hidden:true},
		          {field:'MSG_TITLE',title:'标题',width:400},
		          {field:'ACCOUNT_NAME',title:'发送人',width:100},
		          {field:'SENDTIME',title:'发送时间',width:100},
		          {field:'DEAL_TIME',title:'办理时间',width:100}
		          ]],
		          onDblClickRow:function(index,row){
		        	  openToDoListDetail(row.MSG_ID,row.MSG_TITLE,row.FORM_CODE,row.BUSI_MAIN_ID);
		          }
		
	});
	
}

function reloadGrid(){
	msggrid.datagrid('reload');
}
function searchBasMsg_havdone(){
	msggrid.datagrid('load',{
		msgType : msgType,
		search:$("#searchBasMsg_havdone").val(),
		startDate:$("#startDate").datebox("getValue"),
		endDate:$("#endDate").datebox("getValue"),
		subject:$("#subject").textbox("getValue"),
		flowType: $("#flowType").combotree('getValue') == 0 ? '' : $("#flowType").combotree('getValue')
	});
}

function viewFlowhavedone(){
	var row = msggrid.datagrid('getSelected');
	if (row) {
		viewFlowDialog(row.PROCESSINSTID)
	} else {
		alertInfo('请先选择一条数据信息');
	}
}
function openFormDetail(MSG_TITLE,FORM_CODE,BUSI_MAIN_ID,msgId){
	parent.openInMainTab(MSG_TITLE,"/GenForm/form?newpage=true&formcode="+FORM_CODE+"&isdetail=true&id="+BUSI_MAIN_ID+"&msgId="+msgId); 
}
function openToDoListDetail(msgId,msgTitle,formCode,busMainId,msgUrl){
	var url = "" ;
	if(formCode=='EdocApply'){
		url = "/EdocApply/openPrintPage?id="+busMainId +"&msgId="+msgId;
	}else if(!msgUrl&&'BFmRepayPlan_Form'!=formCode){
		url = "/GenForm/form?formcode="+formCode+"&newpage=true&isdetail=true&id="+busMainId+"&msgId="+msgId;
	}else{
//		var url = '/BasMessage/haveDoneDetail?msgid=' + msgId;
		url = msgUrl+getUrlConnector(msgUrl)+'isdetail=true&msgid=' + msgId;
	}
	if (parent && parent.openInMainTab) {
		 url = url + "&isLayer=Y" ;
		 var l_index = parent.layer.open({
			  type: 2,
			  title: msgTitle,
			  closeBtn: 1, //不显示关闭按钮
			  maxmin: true,
			  skin: 'layui-layer-qllan',
		      zIndex:$.fn.window?Math.ceil($.fn.window.defaults.zIndex++):1001,
	          area: [$(top.window).width() + 'px', $(top.window).height() + 'px'],
			  content: [ctx+url, 'no'], //iframe的url，no代表不显示滚动条
			  success: function (layero, index) {
	         },
	         end: function () {  
					reloadGrid();
//					reloadSubGrid();
	         }
	     });
		// parent.layer.full(l_index);
	} else {
		window.open(ctx + url, '_blank');
	}
}



function openOA(url) {
	window.open(url, '_blank');
	return;
}


function rollbackDoneFlow(){
	var row = msggrid.datagrid('getSelected');
	if (row) {
		if(row.WORKITEMNAME){
			$("#rollAct").html(row.WORKITEMNAME);
			$("#receiveBy").html(row.RECEIVE_BY);
		}
		rollbackFlow(row.MSG_ID,row.BUSI_MAIN_ID,row.FORM_CODE,row.PROCESSINSTID);
	} else {
		alertInfo('请先选择一条数据信息');
	}
}

//流程撤回
function rollbackFlow(msgId,busiMainId,formCode,processinstid){
	$('#rollwin').dialog({
        width: 480,
        height: 300,
        modal: true,
        collapsible: false,
        minimizable: false,
        maximizable: false,
        buttons: [{
            text: '确定',
            handler: function () {
            	if(!$("#rolladvice").textbox("getValue")){
            		alertInfo("请输入撤回原因")
            		return;
            	}
            	alertConfirmYes('您确认要撤回流程？', function(r) {
            		if (r) {
            			layer.msg('数据发送中', {icon: 16, shade: 0.3, time: 0});
            			$.ajax({
            				url : ctx + "/wf/rollbackFlow",
            				data : {
            					msgId : msgId,
            					busiMainId : busiMainId,
            					formCode : formCode,
            					processinstid : processinstid,
            					workmemory : $("#rolladvice").textbox("getValue"),
            					roleType : "撤回"
            				},
            				dataType : 'json',
            				success : function(result) {
            			    	 layer.closeAll();
           		                 $('#rollwin').dialog("close");
            					if (result.success) {
            						alertInfo(result.msg);
            						reloadGrid();
//            						if(msgId){
//            							self.location=ctx+"/BasMessage/todoDetail?msgid="+msgId;
//            						}else{
//            							self.location=ctx+"/EdocApply/toOfficePage?id="+busiMainId+"&type="+(formData.edocType==2?"&type=FWNG":"&type=SWDJ");
//            						}
            						//location.reload(true)
            					} else {
            						alertError(result.msg);
            					}
            				}
            			});
            		}
            	});
            }
        }, {
            text: '取消',
            handler: function () {
                $('#rollwin').dialog("close");
            }
        }]
    });
}
